pro v_fcode, cube, label, FILTER = filter

;+
;
; NAME
;   V_fcode
;
; PURPOSE
;   Filter special values in VIRTIS calibrated cubes
;
; CALLING SEQUENCE:
;   v_FCODE, qube [, label]
;
; INPUTS:
;     Qube = original calibrated cube from virtispds or v_readpds, floating point
;            Must be a named variable (ie: qube, not result.qube)
;     Label =  PDS label (e.g. as returned by V_HEADPDS or V_READPDS)  
;                   string array, optional
;
; OUTPUTS:
;     Qube is filtered, with encoded values replaced by NaN
;     Such values are not displayed by the plot command
;     If argument is integer, these points may be set to 0 (depending on platform?)
;
;
; KEYWORDS
;     FILTER: Filtering option (to be completed)
;          0: no filtering
;          1: filter saturation codes only (default)
;
; EXAMPLE (for testing):
;     d=virtispds('/Volumes/Data2/VEx/calibrations/EGSE_April2007/BIDQH2')
;     d.qube(100, 100) = -1000                                            
;     dd=d.qube                                                           
;     plot, dd(*, 100)  
;     v_fcode, dd     
;     loadct, 12
;     oplot, dd(*, 100), col=200
;
; MODIFICATION HISTORY:
;   Written:     Stephane Erard, LESIA, June 2007
;-



on_error, 0     ; return to main

DefSat  = -1000     ; default Virtis value
If N_elements(filter) EQ 0 then filter = 1     ; keyword not set => filter 
Cind = -1

CASE filter of
1: begin
   If N_params() GE 2 then begin      ; if label provided
       Satcode = v_pdspar(label, "CORE_HIGH_INSTR_SATURATION")
       Isat = size(Satcode, /dim)
       Satcode = Satcode((Isat -1)>0)     ; pick up the last one, for M calibrated 
       If satcode EQ '"NULL"' then Satcode = DefSat
   endif else Satcode = DefSat
   Cind = where(cube EQ Satcode, count)
end
else:      ; do nothing if filter = 0
endcase

;print, count
If Cind(0) NE -1 then cube(Cind) = !values.F_Nan


END