Function V_GetPath, filename, fname

;+
; NAME:
;	V_ GetPath
;
; PURPOSE:
;	Extract directory and filename from a string
;
; CALLING SEQUENCE:
;	Dirname = V_GetPath(filename, Fname)
;
; INPUTS:
;          Filename = full path to the file to be read
;
; OUTPUTS:
;	result = Directory name + final separator ("dir/" under Unix)
;               Empty if not present in input string
;           Fname = File name alone in output
;
; COMMENT:
;          This function works in IDL  5.4, VMS not supported
;          A simpler way exists in IDL 6.0
;
; EXAMPLES:
;          DirName = v_getpath(filename, Fname)
;
; MODIFICATION HISTORY:
;	Written: Stephane Erard, LESIA, LESIA 2007
;	Fix for Windows paths on IDL 6.2, SE, 23/2/2007
;
;--------------------------------------------------------------------


; Equivalent in IDL 6.0 and up:
;      Dname = File_DirName(filename, /mark)
;      Fname = File_BaseName(filename)

      CASE !version.os_family OF
       'unix' :Pathsep="/"
       'MacOS' :Pathsep =":"
       'Windows' :Pathsep ="\"
       ELSE: Pathsep =""     ; assumes data in the same directory
      ENDCASE

;     If !version.os_family EQ 'Win' then begin
;               Dname = filename
;                 Return, Dname
;     endif

      dir = ''
      Dim = strsplit(filename, pathsep, /extract)
        count = (size(dim))(1)
        Fname = Dim(count-1)
        If count GT 1 then $
          Dname = strmid(filename, 0, strlen(filename)-strlen(Fname))$
          else Dname =""
          
     Return, Dname

End