Function V_ListPDS, Dimen0, COUNT=count, SILENT = silent

;+ $Id: v_listpds.pro,v 1.5 2007/02/20 16:15:34 flo Exp $
;
; NAME:
;	V_ListPDS
;
; PURPOSE:
;	Extract values from a list in a PDS label, and return them in an array
;
; CALLING SEQUENCE:
;	result = V_ListPDS(DIMEN)
;
; INPUTS:
;	Dimen =  Value found in PDS label for keywords such as CORE_ITEMS
;	     Should look like '(n1,n2,n3,...)'. Normally an output of v_pdspar 
;               routine. Unchanged on output.
;
; OUTPUTS:
;	result = A N-element integer vector with values in order of apparition.
;               Returns -1 (scalar) if Dimen is not correctly formatted.
;               Values are converted to digits if possible.
;
; OPTIONAL OUTPUTS:
;	COUNT - Optional keyword to return the number of values found
;               in the string. Equals -1 if Dimen is not correctly formatted.
;
; WARNING:
;	Print a message if the list is uncomplete, ie does not end with a ')'
;          This may means that the list of values written on several lines, and
;          should be provided completely (or that the list is followed by a unit).
;
;	SILENT - Disable warning messages.
;
; EXAMPLES:
;	To extract axes names of a Qube (values from AXIS_NAME list):
;
;	IDL> Nax = v_listpds(v_pdspar(h, 'AXIS_NAME'))
;
; MODIFICATION HISTORY:
;	Written: Stephane Erard, IAS, Sept. 2000
;          Updated, SE, Nov 2000 :
;               - Always returns a vector of integers if values are bytes
;          Updated, SE, LESIA, June 2005 :
;               - Returns input argument if not a list, but maintains error code
;
;--------------------------------------------------------------------

      Dimen=strcompress(Dimen0, /remove)
      debut=strmid(dimen,0,1)
      length = strlen(dimen)-1
      fin=strmid(dimen,length,1)
      if debut NE '(' then goto, perdu
      if fin NE ')' then begin
          length = length +1
          pb =1
          if NOT keyword_set(silent) then message, $
             'WARNING - Uncomplete list of values ('+dimen+')', /INF
      endif
      dimen = strmid(dimen,1,length-1)

      if (!version.release GE 5.3) then begin
          Dim = strsplit(dimen, ',', /extract)
          count = (size(dim))(1)
      endif else begin

      Dim=strarr(100)
      count = 0
      while length GT 0 do begin
        count= count+1
        rightp = strpos(dimen,',')
        if rightp EQ -1 then rightp = strlen(dimen)
        Dim(count-1) = strmid(dimen,0,rightp)
        length = strlen(dimen) - rightp
        dimen = strmid(dimen,rightp+1,length)
      endwhile
     Dim = Dim(0:count-1)

    endelse

     a = v_str2num(Dim(0), type=type)
     if type  EQ 1 then type = 2
     Dim0 = Make_array(count, type=type)
     For i=0, count-1 do Dim0(i) = v_str2num(Dim(i))
     return, Dim0

perdu: 
;          Dim0 = [-1]     ; returns nothing if arg is not a list
;          count = -1
          !ERR = -1
          Dim0 = Dimen0
          count = 1
         if NOT keyword_set(silent) then message, $
             'WARNING - Value  ('+dimen+') is not a list', /INF
          return, Dim0

END
